@@ -9,19 +9,20 @@
 #include <QDebug>
 #include <QMetaProperty>
 
-SystemMonitorConfiguration *Configuration::m_config = nullptr;
+Q_GLOBAL_STATIC(SystemMonitorConfiguration, s_config)
+
+SystemMonitorConfiguration *Configuration::globalConfig()
+{
+    return s_config;
+}
 
 Configuration::Configuration(QObject *parent)
     : QObject(parent)
 {
-    if (!m_config) {
-        m_config = new SystemMonitorConfiguration();
-    }
-
     m_saveTimer = std::make_unique<QTimer>();
     m_saveTimer->setInterval(500);
     m_saveTimer->setSingleShot(true);
-    connect(m_saveTimer.get(), &QTimer::timeout, m_config, &SystemMonitorConfiguration::save);
+    connect(m_saveTimer.get(), &QTimer::timeout, globalConfig(), &SystemMonitorConfiguration::save);
 }
 
 void Configuration::propertyChanged()
@@ -32,7 +33,7 @@ void Configuration::propertyChanged()
     auto property = metaObject()->property(metaObject()->indexOfProperty(propertyName));
 
     if (property.isValid()) {
-        m_config->setProperty(property.name(), property.read(this));
+        globalConfig()->setProperty(property.name(), property.read(this));
         m_saveTimer->start();
     } else {
         qWarning() << "Property" << propertyName << "was not found!";
@@ -45,10 +46,6 @@ void Configuration::classBegin()
 
 void Configuration::componentComplete()
 {
-    if (!m_config) {
-        return;
-    }
-
     auto propertyChangedMethod = metaObject()->method(metaObject()->indexOfMethod("propertyChanged()"));
 
     for (auto i = 0; i < metaObject()->propertyCount(); ++i) {
@@ -58,12 +55,12 @@ void Configuration::componentComplete()
             continue;
         }
 
-        if (m_config->metaObject()->indexOfProperty(property.name()) == -1) {
+        if (globalConfig()->metaObject()->indexOfProperty(property.name()) == -1) {
             qWarning() << "Property" << property.name() << "not found in configuration, ignoring";
             continue;
         }
 
-        property.write(this, m_config->property(property.name()));
+        property.write(this, globalConfig()->property(property.name()));
 
         if (property.hasNotifySignal()) {
             connect(this, property.notifySignal(), this, propertyChangedMethod);
